==> pdmclass_1.10.0.tar.gz: pdmclass/man/pdmClass.Rd <==
\name{pdmClass}
\alias{pdmClass}
\title{ Function to Classify Microarray Data using Penalized
  Discriminant Methods }
\description{
  This function is used to classify microarray data. Since the
  underlying model fit is based on penalized discriminant methods, there
  is no need for a pre-filtering step to reduce the number of genes.
}
\usage{
pdmClass(formula , method = c("pls", "pcr", "ridge"), ...)
}
\arguments{
   \item{formula}{A symbolic description of the model to be fit. Details
    given below. }
  \item{method}{ One of "pls", "pcr", "ridge", corresponding to partial
    least squares, principal components regression and ridge regression.}
  \item{\dots}{ Additional parameters to pass to \code{method} or
    \code{\link[mda]{fda}}. See \code{\link[mda]{fda}} for more information.}
}
\details{
  The formula interface is identical to all other formula calls in R,
  namely Y ~ X, where Y is a numeric vector of class assignments and X
  is a matrix or data.frame containing the gene expression values. Note
  that unlike most microarray analyses, in this instance the columns of
  X are genes and rows are samples, so most calls will require something
  similar to Y ~ t(X).
  }
\value{
  an object of class \code{"fda"}.  Use \code{predict} to extract
  discriminant variables, posterior probabilities or predicted class
  memberships.  Other extractor functions are \code{coef},
  and \code{plot}.

  The object has the following components:
  \item{percent.explained}{the percent between-group variance explained
    by each dimension (relative to the total explained.)}
  \item{values}{optimal scaling regresssion sum-of-squares for each
    dimension (see reference).  The usual discriminant analysis
    eigenvalues are given by \code{values / (1-values)}, which are used
    to define \code{percent.explained}.}
  \item{means}{class means in the discriminant space.  These are also
    scaled versions of the final theta's or class scores, and can be
    used in a subsequent call to \code{fda} (this only makes sense if
    some columns of theta are omitted---see the references).} 
  \item{theta.mod}{(internal) a class scoring matrix which allows
    \code{predict} to work properly.}
  \item{dimension}{dimension of discriminant space.}
  \item{prior}{class proportions for the training data.}
  \item{fit}{fit object returned by \code{method}.}
  \item{call}{the call that created this object (allowing it to be
    \code{update}-able)}
  \item{confusion}{A 'confusion' matrix that shows how well the
    classifier works using the training data.}
}
\references{ http://www.sph.umich.edu/~ghoshd/COMPBIO/POPTSCORE

 "Flexible Disriminant Analysis by Optimal Scoring"  by Hastie,
  Tibshirani and Buja, 1994, JASA, 1255-1270.

  "Penalized Discriminant Analysis" by Hastie, Buja and Tibshirani,
  Annals of Statistics, 1995 (in press).
}
\author{James W. MacDonald and Debashis Ghosh, based on \code{fda} in
  the \code{mda} package of Trevor Hastie and Robert Tibshirani, which
  was ported to R by Kurt Hornik, Brian D. Ripley, and Friedrich Leisch.
}
\examples{
library(fibroEset)
data(fibroEset)
y <- as.factor(pData(fibroEset)[,2])
x <- t(exprs(fibroEset))
pdmClass(y ~ x)
}
\keyword{ models}
\keyword{ robust }
\keyword{ classif}

==> pdmclass_1.20.0.tar.gz: pdmclass/man/pdmClass.Rd <==
\name{pdmClass}
\alias{pdmClass}
\title{ Function to Classify Microarray Data using Penalized
  Discriminant Methods }
\description{
  This function is used to classify microarray data. Since the
  underlying model fit is based on penalized discriminant methods, there
  is no need for a pre-filtering step to reduce the number of genes.
}
\usage{
pdmClass(formula , method = c("pls", "pcr", "ridge"), keep.fitted =
TRUE,  ...)
}
\arguments{
   \item{formula}{A symbolic description of the model to be fit. Details
    given below. }
  \item{method}{ One of "pls", "pcr", "ridge", corresponding to partial
    least squares, principal components regression and ridge
    regression.}
  \item{keep.fitted}{Boolean. Should the fitted values be kept? Default
    is TRUE, as this is necessary for the plotting and predict functions.}
  \item{\dots}{ Additional parameters to pass to \code{method} or
    \code{\link[mda]{fda}}. See \code{\link[mda]{fda}} for more information.}
}
\details{
  The formula interface is identical to all other formula calls in R,
  namely Y ~ X, where Y is a numeric vector of class assignments and X
  is a matrix or data.frame containing the gene expression values. Note
  that unlike most microarray analyses, in this instance the columns of
  X are genes and rows are samples, so most calls will require something
  similar to Y ~ t(X).
  }
\value{
  an object of class \code{"fda"}.  Use \code{predict} to extract
  discriminant variables, posterior probabilities or predicted class
  memberships.  Other extractor functions are \code{coef},
  and \code{plot}.

  The object has the following components:
  \item{percent.explained}{the percent between-group variance explained
    by each dimension (relative to the total explained.)}
  \item{values}{optimal scaling regresssion sum-of-squares for each
    dimension (see reference).  The usual discriminant analysis
    eigenvalues are given by \code{values / (1-values)}, which are used
    to define \code{percent.explained}.}
  \item{means}{class means in the discriminant space.  These are also
    scaled versions of the final theta's or class scores, and can be
    used in a subsequent call to \code{fda} (this only makes sense if
    some columns of theta are omitted---see the references).}
  \item{theta.mod}{(internal) a class scoring matrix which allows
    \code{predict} to work properly.}
  \item{dimension}{dimension of discriminant space.}
  \item{prior}{class proportions for the training data.}
  \item{fit}{fit object returned by \code{method}.}
  \item{call}{the call that created this object (allowing it to be
    \code{update}-able)}
  \item{confusion}{A 'confusion' matrix that shows how well the
    classifier works using the training data.}
}
\references{ http://www.sph.umich.edu/~ghoshd/COMPBIO/POPTSCORE

 "Flexible Disriminant Analysis by Optimal Scoring"  by Hastie,
  Tibshirani and Buja, 1994, JASA, 1255-1270.

  "Penalized Discriminant Analysis" by Hastie, Buja and Tibshirani,
  Annals of Statistics, 1995 (in press).
}
\author{James W. MacDonald and Debashis Ghosh, based on \code{fda} in
  the \code{mda} package of Trevor Hastie and Robert Tibshirani, which
  was ported to R by Kurt Hornik, Brian D. Ripley, and Friedrich Leisch.
}
\examples{
library(fibroEset)
data(fibroEset)
y <- as.factor(pData(fibroEset)[,2])
x <- t(exprs(fibroEset))
pdmClass(y ~ x)
}
\keyword{ models}
\keyword{ robust }
\keyword{ classif}
